#!/bin/bash
set -x
source /etc/vdr.d/conf/vdr
source /etc/vdr.d/conf/gen2vdr.cfg

MAN_WAKEUP="/_config/status/ManualStart"
SVDRPCMD="/usr/bin/svdrpsend.pl"
DAILY_WAKEUP=0
TIMER_WAKEUP=0

function check_start()
{
   WAKEUP_FILE="/_config/status/Wakeup"

   # Ist es der taeglicher Wakeup ?
   if [ "$WAKEUP_DURATION" != "" -a $WAKEUP_DURATION -gt 0 ] ; then
      ACT_HOUR=$(date +%k)
      ACT_MINUTE=$(date +%M)
      if [ $WAKEUP_HOUR -eq $ACT_HOUR ] && [ $ACT_MINUTE -lt 10 ] ; then
         DAILY_WAKEUP=1
      elif [ $ACT_MINUTE -gt 50 ] ; then
         if [ $ACT_HOUR -eq 23 -a $WAKEUP_HOUR -eq 0 ] || [ $(($WAKEUP_HOUR -$ACT_HOUR)) -eq 1 ] ; then
            DAILY_WAKEUP=1
         fi
      fi
   fi

   if [ -f $WAKEUP_FILE ] ; then
      ACT_DATE=$(date +%s)
      FDATE=$(ls -l --time-style=+%s $WAKEUP_FILE | tr -s ' ' |cut -f6 -d ' ')
      DIFF=$(($ACT_DATE - $FDATE))
      if [ $DIFF -le 500 ] && [ $DIFF -ge -500 ]; then
         TIMER_WAKEUP=1
      fi
   #   rm -f $WAKEUP_FILE
   fi

   logger "Wakeup: <$DAILY_WAKEUP-$TIMER_WAKEUP>"
}

[ "$(pidof vdrshutdown.sh)" != "" ] && exit

check_start

if [ "$DAILY_WAKEUP" = "1" ] && [ $WAKEUP_DURATION -gt 1 ]; then
   $SVDRPCMD MESG "Sende PowerTaste fuer Shutdown nach DailyWakeup"
   sleep 3
   $SVDRPCMD HITK Back
   $SVDRPCMD HITK Power
   sleep 10
elif [ "$TIMER_WAKEUP" = "1" ] ; then
   # Send Power key for shutting down after Timer
   $SVDRPCMD MESG "Sende PowerTaste fuer Shutdown nach Timer"
   sleep 3
   $SVDRPCMD HITK Back
   $SVDRPCMD HITK Power
   sleep 10
else
   # Remember last manual Startup
   touch $MAN_WAKEUP
fi

[ -f /_config/bin/myinit.sh ] && screen -dm sh -c /_config/bin/myinit.sh
if [ "$AUTOMOUNT" = "1" ] ; then
   if [ "$(cdctl -g | grep "There is no")" = "" ] ; then
      mount /dev/cdrom
   fi	 
   /_config/bin/usbmount.sh -mount
fi
# Get epgdata via epgscan or tvm2vdr
screen -dm sh -c "sh /_config/bin/g2v_epgscan.sh"
# Check for noad tasks to resume
screen -dm sh -c "/_config/bin/check_noad.sh -init"
# check for hw_changes
/_config/bin/detect_hwchanges.sh

if [ "$WATCHDOG" = "0" ] ; then
   DO_RESTART=1
   for i in 1 2 3 4 5 ; do
      if [ "$($SVDRPCMD volu | grep "^250")" != "" ] ; then
         DO_RESTART=0
         break
      fi
      sleep 10
   done
   if [ "$DO_RESTART" = "1" ] ; then
      logger -s "VDR does not respond - Restarting"
      /etc/init.d/vdr stop
      kill -9 $(pidof vdr runvdr)
      /etc/init.d/vdr start

      if [ ! -f /etc/vdrReboot ] && [ ! -f /tmp/.shutdown ] ; then
         sleep 10      
         DO_REBOOT=1
         for i in 1 2 3 4 5 ; do
            if [ "$($SVDRPCMD volu | grep "^250")" != "" ] ; then
               DO_REBOOT=0
               break
            fi
         done
         if [ "$DO_REBOOT" = "1" ] ; then
            logger -s "VDR still does not respond - Rebooting"
            touch /etc/vdrReboot
            screen -dm sh -c "reboot"
            exit
         fi   
      fi
   fi	 
fi      

if [ "$DAILY_WAKEUP" = "1" ] && [ $WAKEUP_DURATION -gt 1 ]; then
   for i in $(seq 1 $WAKEUP_DURATION) ; do
      sleep 60
   done      
fi
[ -f /etc/vdrReboot ] && rm /etc/vdrReboot

